import re
from decimal import Decimal

import requests
from django import template

from wcs.qommon import misc
from wcs.qommon.templatetags.qommon import unlazy

register = template.Library()


@register.filter
def is_valid_belgian_nrn(value):
    return misc.validate_belgian_nrn(unlazy(value))


@register.filter
def is_strong_authentication(session_user):
    return bool('_niss' in session_user.verified_fields)


@register.filter
def liste_type_rdv_plusieurs_personnes(value):
    """
    Anciennement liste_type_general_rdv.py
    value : (str) url api liste des type de rendez-vous
    return : (list[str]) liste des différent type de rendez-vous sans - x personnes
    """
    headers = {'Accept': 'application/json'}
    liste = requests.get(value, headers=headers).json()
    return list(set([re.sub(r" (pour|-) [0-9]+ personne(s)?$", "", x["text"]) for x in liste["data"]]))


@register.filter
def liste_type_rdv_nombres_personnes(value, arg):
    """
    Anciennement liste_type_rdv.py
    value : (str) url api liste des type de rendez-vous
    arg : (str) type de rendez-vous
    return : (list[str]) liste des rendez-vous de type arg
    """
    headers = {'Accept': 'application/json'}
    liste = requests.get(value, headers=headers).json()

    return [x for x in liste["data"] if arg in x["text"]]


@register.filter
def calcul_total_abonnement_stationnement(fields_bloc):
    """
    Anciennement fields_bloc.py
    fields_bloc : (list[dict]) Bloc de champ Abonnements de stationnement données bénéficiaires
    return : (Decimal) addition des entrées price
    """
    total = 0

    for field in fields_bloc:
        for value in field.values():
            if isinstance(value, dict):
                total += Decimal(value.get('price'))

    return total
